=====================================
attrs: Attributes Without Boilerplate
=====================================

Release v\ |release| (:doc:`What's new? <changelog>`).

.. include:: ../README.rst
   :start-after: teaser-begin
   :end-before: -spiel-end-

If you want to know how this looks like, jump right into :doc:`overview`.
If you really want to see ``attrs`` in action, :doc:`examples` will give you a comprehensive rundown of its features.
If you're skeptical and want to know how it works first, check out ":doc:`how-does-it-work`".

.. include:: ../README.rst
   :start-after: -testimonials-
   :end-before: -end-


User's Guide
============

.. toctree::
   :maxdepth: 2

   overview
   why
   examples
   api
   extending
   how-does-it-work


.. include:: ../README.rst
   :start-after: -project-information-

.. toctree::
   :maxdepth: 1

   license
   backward-compatibility
   contributing
   changelog



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
